<?php

/**
 * 企雀科技 接入sdk （默认都是使用GET方式,md5方式加密）
 */
require_once('lib/KdtApiClient.php'); 

class QiQue
{
    private $appId;
    private $appSecret;
    private $distributionAppId;
    private $distributionAppSecret;

    /**
     * @var KdtApiClient
     */
    private $apiClient;

    /**
     * QiQue constructor.
     * @param $appId
     * @param $appSecret
     */
    public function __construct($appId, $appSecret,$distributionAppId,$distributionAppSecret)
    {
        $this->appId = $appId;
        $this->appSecret = $appSecret;
        $this->distributionAppId = $distributionAppId;
        $this->distributionAppSecret = $distributionAppSecret;
        $this->apiClient = new KdtApiClient($appId, $appSecret,$distributionAppId,$distributionAppSecret);
    }
    /**
     * 获取jssdk需要的参数
     *
     * @param  [type] $wxappId         jssdk所对应的公众号的id
     * @param  [type] $url             当前页面的地址，域名需要是js安全域名
     * 返回格式：
     *   array(
     *    "appId",
     *   "nonceStr",
     *    "timestamp",
     *   "url",
     *    "signature",
     *     "rawString"
     *  ) 
     * @return [type]                  [description]
     */
    public function getSignPackage($wxappId, $url){
        $method = 'getsignpackage';
        $params = array(            
            'url' => $url,
            'wxappid' => $wxappId
        );
        $result = $this->apiClient->get($method, $params);
        return $result;
    }
    /** 
     * 在系统里新建一个顾客
     * @param  [type]  $name            必填：顾客名称
     * @param  [type]  $telnum          必填：顾客手机号
     *
     * @param  [type]  $erpId           选填：指定会员id (数字，不超过11位，唯一)
     * @param  integer $sex             选填：顾客性别：（1：男，2：女）
     * @param  [type]  $birthday        选填：生日 Y-m-d
     * @param  [type]  $channelName     选填：渠道名称（和系统内保持一致，系统内没有的时候会新建）
     * @param  string  $channelUserName 选填：渠道人员名称（和系统内保持一致，系统内没有的时候会新建）
     * @param  string  $preConsultName  选填：网电人员名字（和系统内保持一致，系统内没有的时候会新建）
     * @param  string  $ownerName       选填：建档人员名字（和系统内保持一致，系统内没有的时候会新建）
     * @param  string  $description     选填：网电备注（和系统内保持一致，系统内没有的时候会新建）
     * @return [type]             
        {
            errNum: xx(0说明接口返回成功，非0说明是产生了错误)，
            errMsg: errNum为非0时会带上这个错误信息
        }
     */
    public function addCustomer($name, $telnum, $erpId = '', $sex = 0, $birthday = '', $channelName = '', $channelUserName = '', $preConsultName = '', $ownerName = '', $description = ''){
        $method = 'addcustomer';
        $params = array(
            'name' => $name,
            'telnum' => $telnum,
            'sex' => $sex,
            'erpId' => $erpId,
            'birthday' => $birthday,
            'channelName' => $channelName,
            'channelUserName' => $channelUserName,
            'preConsultName' => $preConsultName,
            'ownerName' => $ownerName,
            'description' => $description
        );
        $result = $this->apiClient->post($method, $params);
        return $result;
    }   
    /**
     * 获取顾客的钱包变动记录
     * @param  [type]  $telnum 顾客电话
     * @param  [type]  $type   本次获取明细的类型 22：账户余额 21:佣金 31：积分  选填，默认是31（积分）
     * @param  [type]  $date00 开始时间 Y-m-d H:i:s 选填，默认是当天00:00:00
     * @param  [type]  $date01 结束时间 Y-m-d H:i:s 选填，默认是当天23:59:59
     * @param  integer $page   页数，每页20条  选填，默认是0
     * 成功返回示例：
        {
            errNum: 0,                  // 0代表请求正确返回
            balance: 0,                 // 该顾客的当前余额
            points: 0,                  // 该顾客的当前积分
            commission: 0,              // 该顾客的当前佣金
            // 对应字段的变动明细
            list: {
                id: 6,                      // 变动的编号
                money: 1                    // 对应的金额
                plusOrMinus: 1,             // 用来判断金额是+-，0表示消费，1表示充值
                type: 31,                   // 字段类型 22：账户余额 21:佣金 31：积分
                createTime: '2020-05-26 00:02:03'      // 变动时间
            }
        }         
    */
    public function getWalletChangeList($type = 31, $telnum, $date00 = '', $date01 = '', $page = 0){
        $method = 'getwalletchangelist';
        $params = array(
            'type' => $type,
            'telnum' => $telnum,
            'date00' => $date00,
            'date01' => $date01,
            'page' => $page
        );
        $result = $this->apiClient->post($method, $params);
        return $result;
    }
    /**
     * 调整余额/佣金/积分数量
     * @param  [type] $type  本次变动的类型 22:余额, 21:佣金, 31:积分  选填：默认是31积分
     * @param  [type] $telnum  顾客电话
     * @param  [type] $action  use:使用    add：新增   选填：默认是add
     * @param  [type] $changeNum    调整数量
     * @param  [type] $remark       备注
     * @param  [type] $sendNotify  true 给顾客发送变动通知 false 不给顾客发送变动通知  选填：默认是true 
     *
     * 成功返回示例：
        {
            errNum: 0,                  // 0代表请求正确返回
            errMsg: ''                  // 错误的时候会返回对应的错误信息
        }  
     */
    public function changeWallet($type = 31, $telnum, $action = 'add',  $changeNum = 1, $remark = '',  $sendNotify = true){
        $method = 'changewallet';
        $params = array(
            'type' => $type,
            'telnum' => $telnum,
            'action' => $action,
            'changeNum' => $changeNum,
            'remark' => $remark,
            'sendNotify' => $sendNotify
        );
        $result = $this->apiClient->post($method, $params);
        return $result;
    }

    /**
     * 用cusId获取顾客信息
     * @param  [type] $cusId 用户id
     * @return [type]    
     *  返回顾客信息的字段：    
            id ： ID,
            name ： 名字,
            telnum ： 已认证电话,
            telnum1 ： 未认证电话,
            birthday ： 生日,
            sex ： 性别（1：男，2：女）,
            description ： 额外描述,
            wxLastOpTime ： 微信上最近一次交互的时间,
            uid ： 渠道人员id,
            channelId ： 渠道媒介,
            consultId ： 现场咨询师id,
            firstPreConsultId ： 专属网络咨询师,
            preConsultId ： 网络咨询id,
            intention ： 客户意向度,
            isBigOrder ： 是否是大单,
            points ： 金币,
            commission ： 佣金,
            gold ： 用户余额,
            headimg ： 头像地址,
            orderTime ： 预约时间,
            model ： 0: 公众号聊天 1：网页在线聊天 2:小程序聊天     

            channel ： 媒介的具体信息
            user： 渠道人员的具体信息
            firstpreconsult： 专属咨询师的具体信息
            preconsult： 网络咨询师的具体信息
            consult： 现场咨询师的具体信息
            wxScenesBind: 关注的公众号
     */
    public function getCusInfoByCusId($cusId){
        $method = 'getcusinfobycusid';
        $params = array(
            'cusId' => $cusId
        );
        $result = $this->apiClient->get($method, $params);
        return $result;
    }
    /**
     * 用顾客手机号获取顾客信息
     * @param  [type] $telnum 用户手机号
     */
    public function getCusInfoByTelnum($telnum){
        $method = 'getcusinfobycusid';
        $params = array(
            'telnum' => $telnum
        );
        $result = $this->apiClient->get($method, $params);
        return $result;
    }  

    /**
     * 获得某个时间点之后的所有聊天记录   
     * @param  [type]  $lastChatTime 该时间点之后的聊天内容，空则从最开始获取
     * @param  integer $page         分页，0开始。一页1000条
     * @return [type]  
     *     返回字段说明：
     *        total: 符合条件的消息总数     
     *        consults:              
         *        cusId : 哪个顾客的消息,
         *        msgOwner : 0: 顾客发的，1：客服回复的,  
         *        msgType : 1:文字，2：图片， 3： 音频,4： 视频，5:短视频，         
         *        content : 消息内容,
         *        createTime : 消息创建时间
     */            
    public function getAllChatHistoryByTime($lastChatTime = null, $page = 0){
        $method = 'getallchathistorybytime';
        $params = [];
        $lastChatTime && $params['lastChatTime'] = $lastChatTime;
        $page && $params['page'] = $page;
        $result = $this->apiClient->get($method, $params);
        return $result;        
    }
    /**
     * 获得某个顾客某个时间点之后的聊天记录   
     * @param  [type]  $wxac         公众号的开发者ID(AppID)
     * @param  [type]  $openId       顾客的openId
     * @param  [type]  $lastChatTime 该时间点之后的聊天内容，空则从最开始获取
     * @param  integer $page         分页，0开始。一页20条
     * @return [type]  
     *     返回字段说明：
     *        total: 符合条件的消息总数
     *        cusId: 该顾客在企雀系统中的id
     *        consults:              
         *        cusId : 哪个顾客的消息,
         *        msgOwner : 0: 顾客发的，1：客服回复的,  
         *        msgType : 1:文字，2：图片， 3： 音频,4： 视频，5:短视频，         
         *        content : 消息内容,
         *        createTime : 消息创建时间
     */    
    public function getChatHistoryByOpenId($wxac, $openId, $lastChatTime = null, $page = 0){
        $method = 'getchathistorybyopenid';
        $params = array(
            'wxac' => $wxac,
            'openId' => $openId
        );
        $lastChatTime && $params['lastChatTime'] = $lastChatTime;
        $page && $params['page'] = $page;
        $result = $this->apiClient->get($method, $params);
        return $result;
    }
    /**
     * 获得店内流水
     * @param  [type]  $lastChatTime [description]
     * @param  integer $page         [description]
     * @return [type]                [description]
     */
    public function getOfflinePay($lastPayId = null, $page = 0){
        $method = 'getofflinepay';
        $params = array(
        );
        $lastPayId && $params['lastPayId'] = $lastPayId;
        $page && $params['page'] = $page;
        $result = $this->apiClient->get($method, $params);
        return $result;
    }
    /**
     * 获得店内执行明细
     * @param  [type]  $lastChatTime [description]
     * @param  integer $page         [description]
     * @return [type]                [description]
     */
    public function getOfflineExcute($lastExcuteId = null, $page = 0){
        $method = 'getofflineexcute';
        $params = array(
        );
        $lastExcuteId && $params['lastExcuteId'] = $lastExcuteId;
        $page && $params['page'] = $page;
        $result = $this->apiClient->get($method, $params);
        return $result;
    }
    /**
     * erp内生成一条购买记录
     * @param  [type]  $lastChatTime [description]
     * @param  integer $page         [description]
     * @return [type]                [description]
     */
    public function offlineBuy($telnum, $pName, $money = 0, $num, $buyTime = null){
        $method = 'offlinebuy';
        $params = array(
        );
        $telnum && $params['telnum'] = $telnum;
        $pName && $params['pName'] = $pName;
        $params['money'] = $money;
        $params['num'] = $num;
        $buyTime && $params['buyTime'] = $buyTime;
        $result = $this->apiClient->get($method, $params);
        return $result;
    } 
    /**
     * erp内生成一条划扣记录
     * @param  [type]  $lastChatTime [description]
     * @param  integer $page         [description]
     * @return [type]                [description]
     */
    public function offlineExcute($telnum, $pName, $num, $excuteTime = null){
        $method = 'offlineexcute';
        $params = array(
        );
        $telnum && $params['telnum'] = $telnum;
        $pName && $params['pName'] = $pName;
        $params['num'] = $num;
        $excuteTime && $params['excuteTime'] = $excuteTime;

        $result = $this->apiClient->get($method, $params);
        return $result;
    }    
    /**
     * 店内消费项目
     * @param  integer $type           0： 全部 1：待执行，2：已执行  
     * @param  integer $page           页码
     * @param  integer $cusId          查看某个顾客的信息
     * @return [type] [description]
     */
    public function getOfflineProducts($type = 0, $page = 0, $cusId){
        $method = 'getofflineproducts';
        $params = array(
        );
        $params['type'] = $type;
        $page && $params['page'] = $page;
        $cusId && $params['cusId'] = $cusId;
        $result = $this->apiClient->get($method, $params);
        return $result;
    }    
    /**
     * 获得线上订单的明细
     * @param  [type]  $lastChatTime [description]
     * @return [type]                [description]
     */
    public function getOnlineOrders($lastGetPayTime = null, $lastRefundTime = null){
        $method = 'getonlineorders';
        $params = array(
        );
        $lastGetPayTime && $params['lastGetPayTime'] = $lastGetPayTime;
        $lastRefundTime && $params['lastRefundTime'] = $lastRefundTime;
        $result = $this->apiClient->get($method, $params);
        return $result;
    }
    /**
     * 获得线上商品信息
     * @param  integer $page     [description]
     * @param  integer $goodType 0: 拼团商品，1：普通商品
     * @return [type]            [description]
     */
    public function getGoodsList($page = 0, $goodType = 1){
        $method = 'getgoodslist';
        $params = array(
        );
        $page && $params['page'] = $page;
        $result = $this->apiClient->get($method, $params);
        return $result;
    }
    /**
     * 对某个订单进行发货/核销操作
     * @param  integer $type           0:到店自取，1：自己联系快递(api接口一般是这个)，2：无需快递，3：在线下单，4：签约物流下单
     * @param  [type]  $billId         对应的订单id（优先用这个来查找对应的订单）
     * @param  [type]  $useCode        小程序订单的核销码（如果没有billId，则会根据核销码来查找对应的订单）
     * @param  string  $detailIds      本次发货/核销了这个订单里的哪个商品（不传则全部发货/核销，多个的时候用逗号分隔）
     * @param  [type]  $deliveryCompany 物流公司
     * @param  string  $deliveryNumber  物流编号
     * @param  string  $deliveryComment 物流备注
     * @param  string  $type            0:到店自取，1：自己联系快递，2：无需快递，3：在线下单，4：签约物流下单
     */
    public function delivery($billId = null, $useCode = null, $detailIds = '', $deliveryCompany = null, $deliveryNumber = null, $deliveryComment = null, $type = 1){
        $method = 'delivery';
        $params = array(
        );
        $billId && $params['billId'] = $billId;
        $useCode && $params['useCode'] = $useCode;
        $detailIds && $params['detailIds'] = $detailIds;
        $deliveryCompany && $params['deliveryCompany'] = $deliveryCompany;
        $deliveryNumber && $params['deliveryNumber'] = $deliveryNumber;
        $deliveryComment && $params['deliveryComment'] = $deliveryComment;
        $type && $params['type'] = $type;
        $result = $this->apiClient->get($method, $params);
        return $result;
    }
    /**
     * 获取某个在线订单的订单和商品的信息
     * @param  [type]  $billId         对应的订单id（优先用这个来查找对应的订单）
     * @param  [type]  $useCode        小程序订单的核销码（如果没有billId，则会根据核销码来查找对应的订单）
     * @return [type]          [description]
     */
    public function getOrderDetail($billId = null, $useCode = null){
        $method = 'getorderdetail';
        $params = array(
        );
        $billId && $params['billId'] = $billId;
        $useCode && $params['useCode'] = $useCode;
        $result = $this->apiClient->get($method, $params);
        return $result;
    }    
    /**
     * 获取预约列表（一般用于按时间顺序增量拉取预约或者完成预约的记录）
     * @param  [type] $lastCreateTime   从该“创建预约时间”开始获取预约列表（结果按创建时间排序，不填则不返回结果）
     * @param  [type] $lastCompleteTime 从该“完成预约时间”开始获取预约列表（结果按完成预约时间排序，不填则不返回结果）
     * @param  [type] $lastAppointTime 从该“预约时间”开始获取预约列表（结果按预约时间排序，不填则不返回结果）
     * @param  [type] $cusId    只获取指定顾客的记录
     * @return [type] 返回示例：
        {
            errNum: 0,
            createTotal: "1",
            createList: [
                {
                    id: "898",
                    teamId: "demo",
                    cusId: "13510",
                    uId: "10107",
                    comment: "备注",
                    content: "韩式三点双眼皮2",
                    createTime: "2022-01-04 10:23:14",
                    appointmentTime: "2022-01-04 14:30:00",
                    appointmentTime1: null,
                    cancelTime: null,
                    completeTime: "2022-01-04 10:25:16",
                    type: "3",
                    doctorId: null,
                    pId: null

                }
            ],
            completeTotal: "1",
            completeList: [
                {
                    id: "931",
                    teamId: "demo",
                    cusId: "13552",
                    uId: "10107",
                    comment: "预约备注",
                    content: "全身白瓷3次 韩式三点双眼皮1",
                    createTime: "2022-02-09 16:40:22",
                    appointmentTime: "2022-02-09 18:30:00",
                    appointmentTime1: null,
                    cancelTime: null,
                    completeTime: "2022-02-09 16:41:06",
                    type: "3",
                    doctorId: null,
                    pId: null
                }
            ],
            appointmentTotal: "1",
            appointmentList: [
            ]
        }
     */
    public function getAppointmentList($lastCreateTime = null, $lastCompleteTime = null, $lastAppointTime = null, $cusId = null){
        $method = 'getappointmentlist';
        $params = array(
        );
        $cusId && $params['cusId'] = $cusId;
        $lastCreateTime && $params['lastCreateTime'] = $lastCreateTime;
        $lastCompleteTime && $params['lastCompleteTime'] = $lastCompleteTime;
        $lastAppointTime && $params['lastAppointTime'] = $lastAppointTime;
        $result = $this->apiClient->get($method, $params);
        return $result;
    }
    /**
     * 创建一个预约记录
     * @param  [type] $cusId            顾客id
     * @param  [type] $teamId           所在的企业id
     * @param  [type] $telnum           顾客手机号（顾客id 和 顾客手机号至少填写一个）
     * @param  string $type 0: 到店预约(员工新增在线预约)，3： 到店预约(员工新增店内预约)， 1：手术预约，2：到店预约（顾客在线预约）
     * @param  string $content          预约内容
     * @param  string $comment          预约备注
     * @param  [type] $appointmentTime  预约时间-开始时间（只预约一个时间时使用该字段）
     * @param  [type] $appointmentTime1 预约时间-结束时间
     * @param  [type] $pId 预约的项目（多个的话可以用，分隔）
     * @param  [type] $doctorId 手术排台时预约的工作人员 (此时type需为1)
     * @param  [type] $technicianId 服务的技师id / 服务的设备id
     * 
     * @return [type] 返回示例：
        {
            errNum: 0
        }
     */
    public function addOneAppointment($cusId = null,  $telnum = null, $type = 2, $teamId = null, $content = '', $comment = '', $appointmentTime, $appointmentTime1 = null, $pId, $doctorId = null, $technicianId = null){
        $method = 'addoneappointment';
        $params = array(
        );
        $cusId && $params['cusId'] = $cusId;
        $telnum && $params['telnum'] = $telnum;
        $params['type'] = $type;
        $teamId && $params['teamId'] = $teamId;
        $content && $params['content'] = $content;
        $comment && $params['comment'] = $comment;
        $appointmentTime && $params['appointmentTime'] = $appointmentTime;
        $appointmentTime1 && $params['appointmentTime1'] = $appointmentTime1;
        $pId && $params['pId'] = $pId;
        $doctorId && $params['doctorId'] = $doctorId;
        $technicianId && $params['technicianId'] = $technicianId;
        $result = $this->apiClient->get($method, $params);
        return $result;
    } 
    /**
     * 修改一个预约记录
     * @param  [type] $id            需修改的预约记录的id
     * @param  [type] $teamId           所在的企业id
     * @param  string $type 0: 到店预约(员工新增在线预约)，3： 到店预约(员工新增店内预约)， 1：手术预约，2：到店预约（顾客在线预约）
     * @param  string $content          预约内容
     * @param  string $comment          预约备注
     * @param  [type] $appointmentTime  预约时间-开始时间（只预约一个时间时使用该字段）
     * @param  [type] $appointmentTime1 预约时间-结束时间
     * @param  [type] $pId 预约的项目（多个的话可以用，分隔）
     * @param  [type] $doctorId 手术排台时预约的工作人员 (此时type需为1)
     * @param  [type] $technicianId 服务的技师id / 服务的设备id
     * 
     * @return [type] 返回示例：
        {
            errNum: 0
        }
     */
    public function changeOneAppointment($id, $teamId = null, $type = 2, $content = '', $comment = '', $appointmentTime = null, $appointmentTime1 = null, $pId = null, $doctorId = null, $technicianId = null){
        $method = 'changeappointment';
        $params = array(
        );
        $id && $params['id'] = $id;
        $teamId && $params['teamId'] = $teamId;
        $params['type'] = $type;
        $content && $params['content'] = $content;
        $comment && $params['comment'] = $comment;
        $appointmentTime && $params['appointmentTime'] = $appointmentTime;
        $appointmentTime1 && $params['appointmentTime1'] = $appointmentTime1;
        $pId && $params['pId'] = $pId;
        $doctorId && $params['doctorId'] = $doctorId;
        $technicianId && $params['technicianId'] = $technicianId;
        $result = $this->apiClient->get($method, $params);
        return $result;
    }  
    /**
     * 取消一个预约记录
     * @param  [type] $id      需取消的预约记录的id
     * @param  string $comment 取消预约的备注
     * 
     * @return [type] 返回示例：
        {
            errNum: 0
        }
     */
    public function cancelOneAppointment($id, $comment = ''){
        $method = 'cancelappointment';
        $params = array(
        );
        $id && $params['id'] = $id;
        $comment && $params['comment'] = $comment;
        $result = $this->apiClient->get($method, $params);
        return $result;
    }                                        
    /**
     * 获得顾客列表
     * @param  [type]  $lastId [description]
     * @param  integer $page         [description]
     * @return [type]                [description]
     */
    public function getCustomersList($lastId = 0, $page = 0){
        $method = 'getcustomerslist';
        $params = array(
        );
        $lastId && $params['lastId'] = $lastId;
        $page && $params['page'] = $page;
        $result = $this->apiClient->get($method, $params);
        return $result;
    }

    /**
     * 获得支付方式列表
     * @param  integer $page         [description]
     * @return [type]                [description]
     */
    public function getPayTypeList($page = 0){
        $method = 'getpaytypelist';
        $params = array(
        );
        $page && $params['page'] = $page;
        $result = $this->apiClient->get($method, $params);
        return $result;
    }
    /**
     * 获得渠道列表
     * @param  integer $page         [description]
     * @return [type]                [description]
     */
    public function getChannelList($page = 0){
        $method = 'getchannellist';
        $params = array(
        );
        $page && $params['page'] = $page;
        $result = $this->apiClient->get($method, $params);
        return $result;
    }
    /**
     * 获得员工列表
     * @param  integer $page         [description]
     * @return [type]                [description]
     */
    public function getEmployeeList($page = 0){
        $method = 'getemployeelist';
        $params = array(
        );
        $page && $params['page'] = $page;
        $result = $this->apiClient->get($method, $params);
        return $result;
    }

    /**
     * 给某个手机号发送短信
     *
     * @param  [type]  $tel       发送对象的手机号
     * @param  integer $type      3：发送4位短信验证码（默认）  6：发送商城订单信息
     * @param  [type]  $theParams 如果是发送商城订单信息，格式为theParams: {orderNum:'xxxx', tip:'xxxxxx'}
     *
     * @return [type]             {errNum: xx(0说明接口返回成功，非0说明是产生了错误)，msg: 错误信息}
     */
    public function sendMsgTotel($tel, $type = 3, $theParams = null){
        $method = 'sendmsgtotel';
        $params = array(
            'tel' => $tel,
            'type' => $type
        );
        if($params){
            $params['params'] = json_encode($theParams);
        }
        $result = $this->apiClient->get($method, $params);
        return $result;
    }

    /**
     * 通过openId获取顾客在企雀的id
     *
     * @param  [type] $openId 该顾客的openId
     * @param  [type] $wxappId 微信的appid
     *
     * @return [type]        顾客的id
     */
    public function getCustomerInfo($openId, $wxappId){
        $method = 'getcustomerinfo';
        $params = array(
            'openId' => $openId,
            'wxappid' => $wxappId
        );
        $result = $this->apiClient->get($method, $params);
        return $result;
    }
    /**
     * 给某个顾客发送一张卡或优惠券
     *
     * @param  [type] $cusId           顾客的id
     * @param  [type] $cardOrCouponsId 要发送的卡券的id
     *
     * @return [type]                  [description]
     */
    public function sendCardOrCoupons($cusId, $cardOrCouponsId){
        $method = 'sendcardorcoupons';
        $params = array(
            'cusId' => $cusId,
            'cardOrCouponsId' => $cardOrCouponsId
        );
        $result = $this->apiClient->get($method, $params);
        return $result;
    }

    /**
     * 获取同步卫健委数据
     * @return mixed
     */
    public function getSyncHealthCommissionData(){
        $method = 'getsynchealthcommissiondata';
        $params = array();
        $result = $this->apiClient->get($method, $params);
        return $result;
    }
}